ardt.preprocessors.FixedDuration.FixedDurationPreprocessor
==========================================================

.. currentmodule:: ardt.preprocessors.FixedDuration

.. autoclass:: FixedDurationPreprocessor

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~FixedDurationPreprocessor.__init__
      ~FixedDurationPreprocessor.process_signal
      ~FixedDurationPreprocessor.resolve
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~FixedDurationPreprocessor.context
   
   